package cn.lige2333.qrdouble.common.config;

import com.unfbx.chatgpt.OpenAiClient;
import com.unfbx.chatgpt.OpenAiStreamClient;
import com.unfbx.chatgpt.interceptor.OpenAiResponseInterceptor;
import okhttp3.OkHttpClient;
import org.springframework.ai.chat.memory.ChatMemory;
import org.springframework.ai.chat.memory.InMemoryChatMemory;
import org.springframework.ai.embedding.EmbeddingModel;
import org.springframework.ai.reader.TextReader;
import org.springframework.ai.transformer.splitter.TokenTextSplitter;
import org.springframework.ai.vectorstore.SimpleVectorStore;
import org.springframework.ai.vectorstore.VectorStore;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.CommandLineRunner;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.io.Resource;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.concurrent.TimeUnit;


@Configuration
public class GptConfig {

    @Value("${chatgpt.token}")
    private String token;

    @Bean
    public OkHttpClient okHttpClient() {
        return new OkHttpClient
                .Builder()
                .connectTimeout(1000, TimeUnit.SECONDS)//自定义超时时间
                .writeTimeout(3000, TimeUnit.SECONDS)//自定义超时时间
                .readTimeout(3000, TimeUnit.SECONDS)//自定义超时时间
                .build();
    }
    @Bean
    public OpenAiClient openAiClient() {

        return OpenAiClient.builder()
                .apiKey(Arrays.asList(token))
                .apiHost("http://gptapi.kurtwang.com/")
                .okHttpClient(okHttpClient())
                .build();
    }

    @Bean
    public OpenAiStreamClient openAiStreamClient() {
        return OpenAiStreamClient.builder()
                .apiHost("http://gptapi.kurtwang.com/")
                .apiKey(Arrays.asList(token))
                .okHttpClient(okHttpClient())
                .build();
    }

    @Bean
    public ChatMemory chatMemory(){
        return new InMemoryChatMemory();
    }

    @Bean
    public VectorStore vectorStore(EmbeddingModel embeddingModel){
        return new SimpleVectorStore(embeddingModel);
    }

}
