package cn.lige2333.qrdouble.chatgpt.functions;

import cn.hutool.http.Header;
import cn.hutool.http.HttpRequest;
import cn.lige2333.qrdouble.parking.entity.CardDto;
import cn.lige2333.qrdouble.parking.service.CardService;
import cn.lige2333.qrdouble.stock.entity.Stock;
import cn.lige2333.qrdouble.stock.enums.StockMarket;
import cn.lige2333.qrdouble.stock.service.StockService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Description;
import org.springframework.stereotype.Component;

import java.util.function.Function;

@Component
public class GptFunctions {

    @Autowired
    private StockService stockService;

    @Autowired
    private CardService cardService;

    public record StockSearchRequest(Integer marketCode,String stockCode){}

    public record CardInfoRequest(String userId){}

    public record JenkinsBuildRequest(String projectName){}

    public record StockInfo(String stockCode, String stockName, StockMarket stockMarket,Double currentPrice,Double lastClosePrice,String priceRate){}

    @Bean
    @Description("查找股票信息")
    public Function<StockSearchRequest, StockInfo> findStock(){
        return stockSearchRequest -> {
            Stock stockByCode = stockService.getStockByCode(stockSearchRequest.marketCode(), stockSearchRequest.stockCode());
            return new StockInfo(stockByCode.getStockCode(),stockByCode.getStockName(),StockMarket.getEnumByCode(stockByCode.getStockMarket()),stockByCode.getCurrentPrice(),stockByCode.getLastClosePrice(),stockByCode.getPriceRate());
        };
    }

    @Bean
    @Description("查找打卡信息")
    public Function<CardInfoRequest, CardDto> getCardInfo(){
        return cardInfoRequest -> {
            try {
                return cardService.getCardInfo(cardInfoRequest.userId());
            }catch (Exception e){
                return new CardDto();
            }
        };
    }

    @Bean
    @Description("上班打卡")
    public Function<CardInfoRequest, String> cardOn(){
        return cardInfoRequest -> {
            try {
                String res = cardService.doCardOn(cardInfoRequest.userId());
                if("1".equals(res)){
                    return "成功";
                } else {
                    return "失败";
                }
            }catch (Exception e){
                return "失败";
            }
        };
    }

    @Bean
    @Description("下班打卡")
    public Function<CardInfoRequest, String> cardOff(){
        return cardInfoRequest -> {
           try {
               String res = cardService.doCardOff(cardInfoRequest.userId());
               if("1".equals(res)){
                   return "成功";
               } else {
                   return "失败";
               }
           }catch (Exception e){
               return "失败";
           }
        };
    }

    @Bean
    @Description("Jenkins构建")
    public Function<JenkinsBuildRequest, String> jenkinsBuild(){
        return jenkinsBuildRequest -> {
            try {
                String url = "http://panel.lige2333.cn/buildByToken/build?token=lige2333&job="+jenkinsBuildRequest.projectName();
                String body = HttpRequest.get(url)
                        .timeout(10000)
                        .execute().body();
                return "成功";
            }catch (Exception e){
                return "失败";
            }
        };
    }
}
